{% extends "pinax/announcements/base.html" %} {% load i18n bootstrap %} {% block body %} {% if announcement %} {% url "pinax_announcements:announcement_update" pk=announcement.pk as post_url %} {% else %} {% url "pinax_announcements:announcement_create" as post_url %} {% endif %} {% csrf_token %}

## {% if announcement %}{% trans "Edit Announcement" %}{% else %}{% trans "Create Announcement" %}{% endif %}

{{ form|bootstrap }}
{% trans "Cancel" %} {% if announcement %} {% trans "Delete" %} {% endif %}
{% endblock %}